@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_alami;
 
-our $DATE = '2016-05-23'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-05-27'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,7 +13,7 @@ sub meta {
         enable_by_default => 0,
         might_die => 1,
         prio => 60, # a bit lower than normal
-        precludes => [qr/\Astr_alami(_.+)?\z/],
+        precludes => [qr/\Astr_alami(_.+)?\z/, 'str_natural'],
     };
 }
 
@@ -21,10 +21,11 @@ sub coerce {
     my %args = @_;
 
     my $dt = $args{data_term};
+    my $coerce_to = $args{coerce_to} // 'float(epoch)';
 
     my $res = {};
 
-    unless ($args{coerce_to} eq 'DateTime') {
+    unless ($coerce_to eq 'DateTime') {
         die "To use this coercion rule, you must coerce your date to DateTime (e.g. by adding this attribute 'x.perl.coerce_to' => 'DateTime' to your schema)";
     }
 
@@ -51,7 +52,7 @@ Data::Sah::Coerce::perl::date::str_alami - Coerce date from string parsed by Dat
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-23.
+This document describes version 0.005 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-27.
 
 =head1 DESCRIPTION
 
